@@ -9,6 +9,7 @@ from wetterdienst.provider.dwd.mosmix import DwdMosmixRequest
 from wetterdienst.provider.dwd.observation import DwdObservationRequest
 from wetterdienst.provider.dwd.radar import DwdRadarValues
 from wetterdienst.provider.eccc.observation import EcccObservationRequest
+from wetterdienst.provider.environment_agency.hydrology.api import EaHydrologyRequest
 from wetterdienst.provider.noaa.ghcn.api import NoaaGhcnRequest
 from wetterdienst.provider.wsv.pegel.api import WsvPegelRequest
 from wetterdienst.util.enumeration import parse_enumeration_from_template
@@ -30,6 +31,9 @@ class ApiEndpoints(DatasetTreeCore):
     class WSV(Enum):
         PEGEL = WsvPegelRequest
 
+    class EA(Enum):
+        HYDROLOGY = EaHydrologyRequest
+
 
 class Wetterdienst:
     """Wetterdienst top-level API with links to the different available APIs"""
