@@ -2,11 +2,12 @@
 # Copyright (c) 2018-2021, earthobservations developers.
 # Distributed under the MIT License. See LICENSE for more info.
 import logging
-from datetime import datetime
+from datetime import datetime, timezone
 from itertools import repeat
 from typing import Dict, List, Optional, Union
 
 import pandas as pd
+from pandas import Timedelta, Timestamp
 
 from wetterdienst.core.scalar.request import ScalarRequestCore
 from wetterdienst.core.scalar.values import ScalarValuesCore
@@ -35,13 +36,8 @@ from wetterdienst.provider.dwd.observation.metadata import (
 )
 from wetterdienst.provider.dwd.observation.metadata.field_types import (
     DATE_PARAMETERS_IRREGULAR,
-    INTEGER_PARAMETERS,
     STRING_PARAMETERS,
 )
-from wetterdienst.provider.dwd.observation.metadata.parameter import (
-    PARAMETER_TO_DATASET_MAPPING,
-    DwdObservationDatasetTree,
-)
 from wetterdienst.provider.dwd.observation.metadata.period import DwdObservationPeriod
 from wetterdienst.provider.dwd.observation.metadata.resolution import (
     HIGH_RESOLUTIONS,
@@ -71,9 +67,9 @@ class DwdObservationValues(ScalarValuesCore):
     _data_tz = Timezone.UTC
     _has_quality = True
 
-    _integer_parameters = INTEGER_PARAMETERS
     _string_parameters = STRING_PARAMETERS
-    _irregular_parameters = DATE_PARAMETERS_IRREGULAR
+    _irregular_parameters = ()
+    _date_parameters = DATE_PARAMETERS_IRREGULAR
 
     _resolution_type = ResolutionType.MULTI
     _resolution_base = DwdObservationResolution
@@ -86,9 +82,7 @@ class DwdObservationValues(ScalarValuesCore):
 
         :return:
         """
-        return RESOLUTION_TO_DATETIME_FORMAT_MAPPING.get(
-            self.stations.stations.resolution
-        )
+        return RESOLUTION_TO_DATETIME_FORMAT_MAPPING.get(self.sr.stations.resolution)
 
     def __eq__(self, other):
         """
@@ -97,8 +91,7 @@ class DwdObservationValues(ScalarValuesCore):
         :return:
         """
         return super(DwdObservationValues, self).__eq__(other) and (
-            self.stations.resolution == other.stations.resolution
-            and self.stations.period == other.stations.period
+            self.sr.resolution == other.sr.resolution and self.sr.period == other.sr.period
         )
 
     def __str__(self):
@@ -106,14 +99,12 @@ class DwdObservationValues(ScalarValuesCore):
 
         :return:
         """
-        periods_joined = "& ".join(
-            [period_type.value for period_type in self.stations.period]
-        )
+        periods_joined = "& ".join([period_type.value for period_type in self.sr.period])
 
         return ", ".join(
             [
                 super(DwdObservationValues, self).__str__(),
-                f"resolution {self.stations.resolution.value}",
+                f"resolution {self.sr.resolution.value}",
                 f"periods {periods_joined}",
             ]
         )
@@ -136,11 +127,8 @@ class DwdObservationValues(ScalarValuesCore):
         """
         periods_and_date_ranges = []
 
-        for period in self.stations.period:
-            if (
-                self.stations.resolution in HIGH_RESOLUTIONS
-                and period == Period.HISTORICAL
-            ):
+        for period in self.sr.period:
+            if self.sr.resolution in HIGH_RESOLUTIONS and period == Period.HISTORICAL:
                 date_ranges = self._get_historical_date_ranges(station_id, dataset)
 
                 for date_range in date_ranges:
@@ -148,89 +136,103 @@ class DwdObservationValues(ScalarValuesCore):
             else:
                 periods_and_date_ranges.append((period, None))
 
-        parameter_df = pd.DataFrame()
+        parameter_data = []
 
         for period, date_range in periods_and_date_ranges:
             parameter_identifier = build_parameter_set_identifier(
-                dataset, self.stations.resolution, period, station_id, date_range
+                dataset, self.sr.resolution, period, station_id, date_range
             )
 
             log.info(f"Acquiring observations data for {parameter_identifier}.")
 
-            if not check_dwd_observations_dataset(
-                dataset, self.stations.resolution, period
-            ):
-                log.info(
-                    f"Invalid combination {dataset.value}/"
-                    f"{self.stations.resolution.value}/{period} is skipped."
-                )
+            if not check_dwd_observations_dataset(dataset, self.sr.resolution, period):
+                log.info(f"Invalid combination {dataset.value}/" f"{self.sr.resolution.value}/{period} is skipped.")
 
                 continue
 
             remote_files = create_file_list_for_climate_observations(
-                station_id, dataset, self.stations.resolution, period, date_range
+                station_id, dataset, self.sr.resolution, period, date_range
             )
 
             if len(remote_files) == 0:
                 parameter_identifier = build_parameter_set_identifier(
                     dataset,
-                    self.stations.resolution,
+                    self.sr.resolution,
                     period,
                     station_id,
                     date_range,
                 )
-                log.info(
-                    f"No files found for {parameter_identifier}. Station will be skipped."
-                )
+                log.info(f"No files found for {parameter_identifier}. Station will be skipped.")
                 continue
 
-            # TODO: replace with FSSPEC caching
-            filenames_and_files = download_climate_observations_data_parallel(
-                remote_files
-            )
+            filenames_and_files = download_climate_observations_data_parallel(remote_files)
 
-            period_df = parse_climate_observations_data(
-                filenames_and_files, dataset, self.stations.resolution, period
-            )
+            period_df = parse_climate_observations_data(filenames_and_files, dataset, self.sr.resolution, period)
 
-            # Filter out values which already are in the DataFrame
-            try:
-                period_df = period_df[
-                    ~period_df[DwdColumns.DATE.value].isin(
-                        parameter_df[DwdColumns.DATE.value]
-                    )
-                ]
-            except KeyError:
-                pass
+            parameter_data.append(period_df)
 
-            parameter_df = parameter_df.append(period_df)
+        try:
+            parameter_df = pd.concat(parameter_data)
+        except ValueError:
+            return pd.DataFrame()
+
+        # Filter out values which already are in the DataFrame
+        parameter_df = parameter_df.drop_duplicates(subset=Columns.DATE.value)
+
+        # TODO: temporary fix -> reduce time steps before 2000 by 1 hour
+        #  for 1minute and 10minutes resolution data
+        if not parameter_df.empty:
+            if self.sr.resolution in (Resolution.MINUTE_1, Resolution.MINUTE_10):
+                # Have to parse dates here although they should actually be parsed
+                # later on in the core API
+                parameter_df[Columns.DATE.value] = pd.to_datetime(
+                    parameter_df[Columns.DATE.value], format=self._datetime_format
+                )
+                return self._fix_timestamps(parameter_df)
 
         return parameter_df
 
+    @staticmethod
+    def _fix_timestamps(df: pd.DataFrame) -> pd.DataFrame:
+        """
+        This method is used to fix timestamps for 10 minute resolution data provided
+        by DWD. The original document states
+        " The time stamp before the year 2000 is given in MEZ, the time stamp after
+        the year 2000 is given in UTC. "
+        :param df: pandas DataFrame with original timestamps
+        :return: pandas DataFrame with fixed timestamps
+        """
+        before_2000 = df[Columns.DATE.value].dt.year < 2000
+
+        df.loc[before_2000, Columns.DATE.value] -= Timedelta(hours=1)
+
+        return df
+
     def _tidy_up_df(self, df: pd.DataFrame, dataset) -> pd.DataFrame:
         """
         Implementation of _tidy_up_df for DWD Observations
 
-        :param df:
-        :param dataset:
-        :return:
+        :param df: untidy DataFrame
+        :param dataset: dataset enumeration
+        :return: tidied DataFrame
         """
-        resolution = self.stations.stations.resolution
 
         droppable_columns = [
             # Hourly
             # Cloud type
-            DwdObservationDatasetTree.HOURLY.CLOUD_TYPE.CLOUD_TYPE_LAYER1_ABBREVIATION.value,  # noqa:E501
-            DwdObservationDatasetTree.HOURLY.CLOUD_TYPE.CLOUD_TYPE_LAYER2_ABBREVIATION.value,  # noqa:E501
-            DwdObservationDatasetTree.HOURLY.CLOUD_TYPE.CLOUD_TYPE_LAYER3_ABBREVIATION.value,  # noqa:E501
-            DwdObservationDatasetTree.HOURLY.CLOUD_TYPE.CLOUD_TYPE_LAYER4_ABBREVIATION.value,  # noqa:E501
+            DwdObservationParameter.HOURLY.CLOUD_TYPE.CLOUD_TYPE_LAYER1_ABBREVIATION.value,
+            DwdObservationParameter.HOURLY.CLOUD_TYPE.CLOUD_TYPE_LAYER2_ABBREVIATION.value,
+            DwdObservationParameter.HOURLY.CLOUD_TYPE.CLOUD_TYPE_LAYER3_ABBREVIATION.value,
+            DwdObservationParameter.HOURLY.CLOUD_TYPE.CLOUD_TYPE_LAYER4_ABBREVIATION.value,
             # Cloudiness
-            DwdObservationDatasetTree.HOURLY.CLOUDINESS.CLOUD_COVER_TOTAL_INDICATOR.value,  # noqa:E501
+            DwdObservationParameter.HOURLY.CLOUDINESS.CLOUD_COVER_TOTAL_INDICATOR.value,
             # Solar
-            DwdObservationDatasetTree.HOURLY.SOLAR.END_OF_INTERVAL.value,
-            DwdObservationDatasetTree.HOURLY.SOLAR.TRUE_LOCAL_TIME.value,
+            DwdObservationParameter.HOURLY.SOLAR.END_OF_INTERVAL.value,
+            DwdObservationParameter.HOURLY.SOLAR.TRUE_LOCAL_TIME.value,
             # Visibility
-            DwdObservationDatasetTree.HOURLY.VISIBILITY.VISIBILITY_INDICATOR.value,
+            DwdObservationParameter.HOURLY.VISIBILITY.VISIBILITY_RANGE_INDICATOR.value,
+            # Weather
+            DwdObservationParameter.HOURLY.WEATHER_PHENOMENA.WEATHER_TEXT.value,
         ]
 
         # Drop string columns, can't be coerced to float
@@ -239,41 +241,35 @@ class DwdObservationValues(ScalarValuesCore):
             errors="ignore",
         )
 
-        if (
-            resolution == Resolution.DAILY
-            and dataset == DwdObservationDataset.CLIMATE_SUMMARY
-        ):
-            quality_wind = df.pop(
-                DwdObservationDatasetTree.DAILY.CLIMATE_SUMMARY.QUALITY_WIND.value
-            )
-            quality_general = df.pop(
-                DwdObservationDatasetTree.DAILY.CLIMATE_SUMMARY.QUALITY_GENERAL.value
-            )
+        resolution = self.sr.stations.resolution
 
-            quality = pd.concat(
-                [
-                    pd.Series(repeat(quality_wind.tolist(), 2)).explode(),
-                    pd.Series(repeat(quality_general.tolist(), 12)).explode(),
-                ]
-            )
+        if dataset == DwdObservationDataset.CLIMATE_SUMMARY:
+            if resolution == Resolution.DAILY:
+                quality_wind = df.pop(DwdObservationParameter.DAILY.CLIMATE_SUMMARY.QUALITY_WIND.value)
+                quality_general = df.pop(DwdObservationParameter.DAILY.CLIMATE_SUMMARY.QUALITY_GENERAL.value)
 
-        elif (
-            resolution in (Resolution.MONTHLY, Resolution.ANNUAL)
-            and dataset == DwdObservationDataset.CLIMATE_SUMMARY
-        ):
-            quality_general = df.pop(
-                DwdObservationDatasetTree.MONTHLY.CLIMATE_SUMMARY.QUALITY_GENERAL.value
-            )
-            quality_precipitation = df.pop(
-                DwdObservationDatasetTree.MONTHLY.CLIMATE_SUMMARY.QUALITY_PRECIPITATION.value  # noqa: E501
-            )
-            quality = pd.concat(
-                [
-                    pd.Series(repeat(quality_general, 9)).explode(),
-                    pd.Series(repeat(quality_precipitation, 2)).explode(),
-                ]
-            )
+                quality = pd.concat(
+                    [
+                        pd.Series(repeat(quality_wind.tolist(), 2)).explode(),
+                        pd.Series(repeat(quality_general.tolist(), 12)).explode(),
+                    ]
+                )
 
+            elif resolution in (Resolution.MONTHLY, Resolution.ANNUAL):
+                quality_general = df.pop(DwdObservationParameter.MONTHLY.CLIMATE_SUMMARY.QUALITY_GENERAL.value)
+                quality_precipitation = df.pop(
+                    DwdObservationParameter.MONTHLY.CLIMATE_SUMMARY.QUALITY_PRECIPITATION.value
+                )
+                quality = pd.concat(
+                    [
+                        pd.Series(repeat(quality_general, 9)).explode(),
+                        pd.Series(repeat(quality_precipitation, 2)).explode(),
+                    ]
+                )
+        elif resolution == Resolution.SUBDAILY and DwdObservationDataset.WIND_EXTREME:
+            quality_fx_3 = df.pop("qn_8_3")
+            quality_fx_6 = df.pop("qn_8_6")
+            quality = pd.concat([quality_fx_3, quality_fx_6])
         else:
             quality = df.pop(df.columns[2])
             quality = pd.Series(repeat(quality, df.shape[1])).explode()
@@ -292,12 +288,11 @@ class DwdObservationValues(ScalarValuesCore):
             var_name=Columns.PARAMETER.value,
             value_name=Columns.VALUE.value,
         )
-
         df_tidy[Columns.QUALITY.value] = quality.reset_index(drop=True)
 
         return df_tidy
 
-    def _coerce_dates(self, series: pd.Series) -> pd.Series:
+    def _coerce_dates(self, series: pd.Series, timezone_: timezone) -> pd.Series:
         """
         Use predefined datetime format for given resolution to reduce processing
         time.
@@ -305,9 +300,10 @@ class DwdObservationValues(ScalarValuesCore):
         :param series:
         :return:
         """
-        return pd.to_datetime(series, format=self._datetime_format).dt.tz_localize(
-            self.data_tz
-        )
+        series = pd.to_datetime(series, format=self._datetime_format)
+        if not series.dt.tz:
+            return series.dt.tz_localize(self.data_tz)
+        return series
 
     def _coerce_irregular_parameter(self, series: pd.Series) -> pd.Series:
         """
@@ -326,16 +322,17 @@ class DwdObservationValues(ScalarValuesCore):
 
         :return:
         """
-        hcnm = {
-            parameter.value: parameter.name.lower()
-            for parameter in DwdObservationParameter[self.stations.resolution.name]
-        }
+        hpm = {}
 
-        return hcnm
+        for parameter in DwdObservationParameter[self.sr.resolution.name]:
+            try:
+                hpm[parameter.value] = parameter.name.lower()
+            except AttributeError:
+                pass
 
-    def _get_historical_date_ranges(
-        self, station_id: str, dataset: DwdObservationDataset
-    ) -> List[str]:
+        return hpm
+
+    def _get_historical_date_ranges(self, station_id: str, dataset: DwdObservationDataset) -> List[str]:
         """
         Get particular files for historical data which for high resolution is
         released in data chunks e.g. decades or monthly chunks
@@ -344,14 +341,14 @@ class DwdObservationValues(ScalarValuesCore):
         :param dataset:
         :return:
         """
-        file_index = create_file_index_for_climate_observations(
-            dataset, self.stations.resolution, Period.HISTORICAL
-        )
+        file_index = create_file_index_for_climate_observations(dataset, self.sr.resolution, Period.HISTORICAL)
+
+        file_index = file_index[(file_index[Columns.STATION_ID.value] == station_id)]
 
         # The request interval may be None, if no start and end date
         # is given but rather the entire available data is queried.
         # In this case the interval should overlap with all files
-        interval = self.stations.stations._interval
+        interval = self.sr.stations._interval
 
         if not interval:
             from_date_min = file_index[Columns.FROM_DATE.value].min()
@@ -387,10 +384,9 @@ class DwdObservationRequest(ScalarRequestCore):
     _period_base = DwdObservationPeriod
     _data_range = DataRange.FIXED
     _has_datasets = True
+    _has_tidy_data = False
     _unique_dataset = False
     _dataset_base = DwdObservationDataset
-    _dataset_tree = DwdObservationDatasetTree
-    _parameter_to_dataset_mapping = PARAMETER_TO_DATASET_MAPPING
 
     _unit_tree = DwdObservationUnit
 
@@ -402,7 +398,10 @@ class DwdObservationRequest(ScalarRequestCore):
         :return:
         """
         if self.start_date:
-            return pd.Interval(self.start_date, self.end_date, closed="both")
+            # cut of hours, seconds,...
+            start_date = Timestamp(self.start_date).tz_convert(self.tz)
+            end_date = Timestamp(self.end_date).tz_convert(self.tz)
+            return pd.Interval(start_date, end_date, closed="both")
 
         return None
 
@@ -416,16 +415,10 @@ class DwdObservationRequest(ScalarRequestCore):
         """
         historical_end = self._now_local.replace(month=1, day=1)
 
-        if self.start_date < historical_end:
-            historical_begin = self.start_date.tz_convert(historical_end.tz)
-        else:
-            historical_begin = historical_end + pd.tseries.offsets.DateOffset(years=-1)
+        # a year that is way before any data is collected
+        historical_begin = pd.Timestamp(datetime(year=1678, month=1, day=1)).tz_localize(historical_end.tz)
 
-        historical_interval = pd.Interval(
-            left=historical_begin, right=historical_end, closed="both"
-        )
-
-        return historical_interval
+        return pd.Interval(left=historical_begin, right=historical_end, closed="both")
 
     @property
     def _recent_interval(self) -> pd.Interval:
@@ -438,11 +431,7 @@ class DwdObservationRequest(ScalarRequestCore):
         recent_end = self._now_local.replace(hour=0, minute=0, second=0)
         recent_begin = recent_end - pd.Timedelta(days=500)
 
-        recent_interval = pd.Interval(
-            left=recent_begin, right=recent_end, closed="both"
-        )
-
-        return recent_interval
+        return pd.Interval(left=recent_begin, right=recent_end, closed="both")
 
     @property
     def _now_interval(self) -> pd.Interval:
@@ -455,9 +444,7 @@ class DwdObservationRequest(ScalarRequestCore):
         now_end = self._now_local
         now_begin = now_end.replace(hour=0, minute=0, second=0) - pd.Timedelta(days=1)
 
-        now_interval = pd.Interval(left=now_begin, right=now_end, closed="both")
-
-        return now_interval
+        return pd.Interval(left=now_begin, right=now_end, closed="both")
 
     def _get_periods(self) -> List[Period]:
         """
@@ -491,9 +478,7 @@ class DwdObservationRequest(ScalarRequestCore):
         """
         series = super(DwdObservationRequest, self)._parse_station_id(series)
 
-        series = series.str.pad(5, "left", "0")
-
-        return series
+        return series.str.pad(5, "left", "0")
 
     def __init__(
         self,
@@ -502,17 +487,14 @@ class DwdObservationRequest(ScalarRequestCore):
         period: Optional[Union[str, Period, DwdObservationPeriod]] = None,
         start_date: Optional[Union[str, datetime, pd.Timestamp]] = None,
         end_date: Optional[Union[str, datetime, pd.Timestamp]] = None,
-        humanize: bool = True,
-        tidy: bool = True,
-        si_units: bool = True,
     ):
         """
 
         :param parameter: parameter set str/enumeration
         :param resolution: resolution str/enumeration
         :param period: period str/enumeration
-        :param start_date: start date to limit the stations
-        :param end_date: end date to limit the stations
+        :param start_date: start date to limit the stations_result
+        :param end_date: end date to limit the stations_result
         """
         super().__init__(
             parameter=parameter,
@@ -520,16 +502,10 @@ class DwdObservationRequest(ScalarRequestCore):
             period=period,
             start_date=start_date,
             end_date=end_date,
-            humanize=humanize,
-            tidy=tidy,
-            si_units=si_units,
         )
 
         if self.start_date and self.period:
-            log.warning(
-                f"start_date and end_date filtering limited to defined "
-                f"periods {self.period}"
-            )
+            log.warning(f"start_date and end_date filtering limited to defined " f"periods {self.period}")
 
         # Has to follow the super call as start date and end date are required for getting
         # automated periods from overlapping intervals
@@ -549,10 +525,10 @@ class DwdObservationRequest(ScalarRequestCore):
         :param language:
         :return:
         """
+        from wetterdienst.provider.dwd.observation.fields import read_description
+
         dataset = parse_enumeration_from_template(dataset, DwdObservationDataset)
-        resolution = parse_enumeration_from_template(
-            resolution, cls._resolution_base, Resolution
-        )
+        resolution = parse_enumeration_from_template(resolution, cls._resolution_base, Resolution)
         period = parse_enumeration_from_template(period, cls._period_base, Period)
 
         file_index = _create_file_index_for_dwd_server(
@@ -569,18 +545,12 @@ class DwdObservationRequest(ScalarRequestCore):
         else:
             raise ValueError("Only language 'en' or 'de' supported")
 
-        file_index = file_index[
-            file_index[DwdColumns.FILENAME.value].str.contains(file_prefix)
-        ]
+        file_index = file_index[file_index[DwdColumns.FILENAME.value].str.contains(file_prefix)]
 
         description_file_url = str(file_index[DwdColumns.FILENAME.value].tolist()[0])
         log.info(f"Acquiring field information from {description_file_url}")
 
-        from wetterdienst.provider.dwd.observation.fields import read_description
-
-        document = read_description(description_file_url, language=language)
-
-        return document
+        return read_description(description_file_url, language=language)
 
     def _all(self) -> pd.DataFrame:
         """
@@ -589,7 +559,7 @@ class DwdObservationRequest(ScalarRequestCore):
         """
         datasets = pd.Series(self.parameter).map(lambda x: x[1]).unique()
 
-        stations_df = pd.DataFrame()
+        stations = []
 
         for dataset in datasets:
             # First "now" period as it has more updated end date up to the last "now"
@@ -597,38 +567,27 @@ class DwdObservationRequest(ScalarRequestCore):
             for period in reversed(self.period):
                 if not check_dwd_observations_dataset(dataset, self.resolution, period):
                     log.warning(
-                        f"The combination of {dataset.value}, "
-                        f"{self.resolution.value}, {period.value} is invalid."
+                        f"The combination of {dataset.value}, " f"{self.resolution.value}, {period.value} is invalid."
                     )
 
                     continue
 
-                df = create_meta_index_for_climate_observations(
-                    dataset, self.resolution, period
-                )
+                df = create_meta_index_for_climate_observations(dataset, self.resolution, period)
 
-                file_index = create_file_index_for_climate_observations(
-                    dataset, self.resolution, period
-                )
+                file_index = create_file_index_for_climate_observations(dataset, self.resolution, period)
 
-                df = df[
-                    df.loc[:, Columns.STATION_ID.value].isin(
-                        file_index[Columns.STATION_ID.value]
-                    )
-                ]
+                df = df[df.loc[:, Columns.STATION_ID.value].isin(file_index[Columns.STATION_ID.value])]
 
-                if not stations_df.empty:
-                    df = df[
-                        ~df[Columns.STATION_ID.value].isin(
-                            stations_df[Columns.STATION_ID.value]
-                        )
-                    ]
+                stations.append(df)
 
-                stations_df = stations_df.append(df)
+        try:
+            stations_df = pd.concat(stations)
+        except ValueError:
+            return pd.DataFrame()
+
+        stations_df = stations_df.drop_duplicates(subset=Columns.STATION_ID.value, keep="first")
 
         if not stations_df.empty:
-            stations_df = stations_df.sort_values(
-                [Columns.STATION_ID.value], key=lambda x: x.astype(int)
-            )
+            return stations_df.sort_values([Columns.STATION_ID.value], key=lambda x: x.astype(int))
 
         return stations_df
