@@ -302,6 +302,9 @@ class DwdObservationParameter(DatasetTreeCore):
         VISIBILITY_RANGE_INDICATOR = VISIBILITY.VISIBILITY_RANGE_INDICATOR
         VISIBILITY_RANGE = VISIBILITY.VISIBILITY_RANGE
 
+        # weather phenomena
+        WEATHER = WEATHER_PHENOMENA.WEATHER
+
         # wind
         WIND_SPEED = WIND.WIND_SPEED
         WIND_DIRECTION = WIND.WIND_DIRECTION
