@@ -33,20 +33,20 @@ class DwdObservationUnit(DatasetTreeCore):
         # air_temperature
         class TEMPERATURE_AIR(UnitEnum):  # noqa
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            PRESSURE_AIR_STATION_HEIGHT = (
+            PRESSURE_AIR_SITE = (
                 OriginUnit.HECTOPASCAL.value,
                 SIUnit.PASCAL.value,
             )
-            TEMPERATURE_AIR_200 = (
+            TEMPERATURE_AIR_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_AIR_005 = (
+            TEMPERATURE_AIR_MEAN_005 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
             HUMIDITY = OriginUnit.PERCENT.value, SIUnit.PERCENT.value
-            TEMPERATURE_DEW_POINT_200 = (
+            TEMPERATURE_DEW_POINT_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -86,7 +86,7 @@ class DwdObservationUnit(DatasetTreeCore):
                 OriginUnit.METER_PER_SECOND.value,
                 SIUnit.METER_PER_SECOND.value,
             )
-            WIND_DIRECTION_MAX_VELOCITY = (
+            WIND_DIRECTION_GUST_MAX = (
                 OriginUnit.WIND_DIRECTION.value,
                 SIUnit.WIND_DIRECTION.value,
             )
@@ -107,7 +107,7 @@ class DwdObservationUnit(DatasetTreeCore):
         # solar
         class SOLAR(UnitEnum):
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            RADIATION_SKY_DIFFUSE = (
+            RADIATION_SKY_SHORT_WAVE_DIFFUSE = (
                 OriginUnit.JOULE_PER_SQUARE_CENTIMETER.value,
                 SIUnit.JOULE_PER_SQUARE_METER.value,
             )
@@ -135,7 +135,7 @@ class DwdObservationUnit(DatasetTreeCore):
         # air_temperature
         class TEMPERATURE_AIR(UnitEnum):  # noqa
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            TEMPERATURE_AIR_200 = (
+            TEMPERATURE_AIR_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -202,11 +202,42 @@ class DwdObservationUnit(DatasetTreeCore):
         # dew_point
         class DEW_POINT(UnitEnum):  # noqa
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            TEMPERATURE_AIR_200 = (
+            TEMPERATURE_AIR_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_DEW_POINT_200 = (
+            TEMPERATURE_DEW_POINT_MEAN_200 = (
+                OriginUnit.DEGREE_CELSIUS.value,
+                SIUnit.DEGREE_KELVIN.value,
+            )
+
+        # extreme_wind
+        class WIND_EXTREME(UnitEnum):  # noqa
+            QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            WIND_GUST_MAX = (
+                OriginUnit.METER_PER_SECOND.value,
+                SIUnit.METER_PER_SECOND.value,
+            )
+
+        # moisture
+        class MOISTURE(UnitEnum):
+            QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            HUMIDITY_ABSOLUTE = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            PRESSURE_VAPOR = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
+            TEMPERATURE_WET_MEAN_200 = (
+                OriginUnit.DEGREE_CELSIUS.value,
+                SIUnit.DEGREE_KELVIN.value,
+            )
+            PRESSURE_AIR_SITE = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
+            TEMPERATURE_AIR_MEAN_200 = (
+                OriginUnit.DEGREE_CELSIUS.value,
+                SIUnit.DEGREE_KELVIN.value,
+            )
+            HUMIDITY = OriginUnit.PERCENT.value, SIUnit.PERCENT.value
+            TEMPERATURE_DEW_POINT_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -234,7 +265,7 @@ class DwdObservationUnit(DatasetTreeCore):
                 OriginUnit.HECTOPASCAL.value,
                 SIUnit.PASCAL.value,
             )
-            PRESSURE_AIR_STATION_HEIGHT = (
+            PRESSURE_AIR_SITE = (
                 OriginUnit.HECTOPASCAL.value,
                 SIUnit.PASCAL.value,
             )
@@ -242,27 +273,27 @@ class DwdObservationUnit(DatasetTreeCore):
         # soil_temperature
         class TEMPERATURE_SOIL(UnitEnum):  # noqa
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            TEMPERATURE_SOIL_002 = (
+            TEMPERATURE_SOIL_MEAN_002 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_SOIL_005 = (
+            TEMPERATURE_SOIL_MEAN_005 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_SOIL_010 = (
+            TEMPERATURE_SOIL_MEAN_010 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_SOIL_020 = (
+            TEMPERATURE_SOIL_MEAN_020 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_SOIL_050 = (
+            TEMPERATURE_SOIL_MEAN_050 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_SOIL_100 = (
+            TEMPERATURE_SOIL_MEAN_100 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -287,25 +318,31 @@ class DwdObservationUnit(DatasetTreeCore):
                 SIUnit.JOULE_PER_SQUARE_METER.value,
             )
             SUNSHINE_DURATION = OriginUnit.MINUTE.value, SIUnit.SECOND.value
-            SUN_ZENITH = OriginUnit.DEGREE.value, SIUnit.DEGREE.value
+            SUN_ZENITH_ANGLE = OriginUnit.DEGREE.value, SIUnit.DEGREE.value
             TRUE_LOCAL_TIME = (
                 OriginUnit.DIMENSIONLESS.value,
                 SIUnit.DIMENSIONLESS.value,
             )
 
         # sun
-        class SUNSHINE_DURATION(UnitEnum):
+        class SUN(UnitEnum):
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
             SUNSHINE_DURATION = OriginUnit.MINUTE.value, SIUnit.SECOND.value
 
         # visibility
         class VISIBILITY(UnitEnum):
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            VISIBILITY_INDICATOR = (
+            VISIBILITY_RANGE_INDICATOR = (
                 OriginUnit.DIMENSIONLESS.value,
                 SIUnit.DIMENSIONLESS.value,
             )
-            VISIBILITY = OriginUnit.METER.value, SIUnit.METER.value
+            VISIBILITY_RANGE = OriginUnit.METER.value, SIUnit.METER.value
+
+        # weather_phenomena
+        class WEATHER_PHENOMENA(UnitEnum):
+            QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            WEATHER = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            WEATHER_TEXT = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
 
         # wind
         class WIND(UnitEnum):
@@ -331,34 +368,12 @@ class DwdObservationUnit(DatasetTreeCore):
                 SIUnit.WIND_DIRECTION.value,
             )
 
-        class MOISTURE(UnitEnum):
-            QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            HUMIDITY_ABSOLUTE = (
-                OriginUnit.DIMENSIONLESS.value,
-                SIUnit.DIMENSIONLESS.value,
-            )
-            PRESSURE_VAPOR = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
-            TEMPERATURE_WET = (
-                OriginUnit.DEGREE_CELSIUS.value,
-                SIUnit.DEGREE_KELVIN.value,
-            )
-            PRESSURE_AIR = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
-            TEMPERATURE_AIR_200 = (
-                OriginUnit.DEGREE_CELSIUS.value,
-                SIUnit.DEGREE_KELVIN.value,
-            )
-            HUMIDITY = OriginUnit.PERCENT.value, SIUnit.PERCENT.value
-            TEMPERATURE_DEW_POINT_200 = (
-                OriginUnit.DEGREE_CELSIUS.value,
-                SIUnit.DEGREE_KELVIN.value,
-            )
-
     # subdaily
     class SUBDAILY(DatasetTreeCore):  # noqa
         # air_temperature
         class TEMPERATURE_AIR(UnitEnum):  # noqa
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            TEMPERATURE_AIR_200 = (
+            TEMPERATURE_AIR_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -373,15 +388,28 @@ class DwdObservationUnit(DatasetTreeCore):
                 SIUnit.DIMENSIONLESS.value,
             )
 
+        # extreme_wind
+        class WIND_EXTREME(UnitEnum):
+            QUALITY_3 = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            WIND_GUST_MAX_LAST_3H = (
+                OriginUnit.METER_PER_SECOND.value,
+                SIUnit.METER_PER_SECOND.value,
+            )
+            QUALITY_6 = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            WIND_GUST_MAX_LAST_6H = (
+                OriginUnit.METER_PER_SECOND.value,
+                SIUnit.METER_PER_SECOND.value,
+            )
+
         # moisture
         class MOISTURE(UnitEnum):
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
             PRESSURE_VAPOR = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
-            TEMPERATURE_AIR_005 = (
+            TEMPERATURE_AIR_MEAN_005 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_AIR_200 = (
+            TEMPERATURE_AIR_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -390,12 +418,12 @@ class DwdObservationUnit(DatasetTreeCore):
         # pressure
         class PRESSURE(UnitEnum):
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            PRESSURE_AIR = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
+            PRESSURE_AIR_SITE = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
 
         # soil
         class SOIL(UnitEnum):
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            TEMPERATURE_SOIL_005 = (
+            TEMPERATURE_SOIL_MEAN_005 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -403,7 +431,7 @@ class DwdObservationUnit(DatasetTreeCore):
         # visibility
         class VISIBILITY(UnitEnum):
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            VISIBILITY = OriginUnit.METER.value, SIUnit.METER.value
+            VISIBILITY_RANGE = OriginUnit.METER.value, SIUnit.METER.value
 
         # wind
         class WIND(UnitEnum):
@@ -443,8 +471,8 @@ class DwdObservationUnit(DatasetTreeCore):
             SNOW_DEPTH = OriginUnit.CENTIMETER.value, SIUnit.METER.value
             CLOUD_COVER_TOTAL = OriginUnit.ONE_EIGHTH.value, SIUnit.PERCENT.value
             PRESSURE_VAPOR = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
-            PRESSURE_AIR = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
-            TEMPERATURE_AIR_200 = (
+            PRESSURE_AIR_SITE = OriginUnit.HECTOPASCAL.value, SIUnit.PASCAL.value
+            TEMPERATURE_AIR_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -476,26 +504,38 @@ class DwdObservationUnit(DatasetTreeCore):
             SNOW_DEPTH = OriginUnit.CENTIMETER.value, SIUnit.METER.value
             SNOW_DEPTH_NEW = OriginUnit.CENTIMETER.value, SIUnit.METER.value
 
+        # more_weather_phenomena
+        class WEATHER_PHENOMENA_MORE(UnitEnum):  # noqa
+            QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            COUNT_WEATHER_TYPE_SLEET = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            COUNT_WEATHER_TYPE_HAIL = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            COUNT_WEATHER_TYPE_FOG = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+            COUNT_WEATHER_TYPE_THUNDER = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
+
         # soil_temperature
         class TEMPERATURE_SOIL(UnitEnum):  # noqa
             QUALITY = OriginUnit.DEGREE_CELSIUS.value, SIUnit.DIMENSIONLESS.value
-            TEMPERATURE_SOIL_002 = (
+            TEMPERATURE_SOIL_MEAN_002 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_SOIL_005 = (
+            TEMPERATURE_SOIL_MEAN_005 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_SOIL_010 = (
+            TEMPERATURE_SOIL_MEAN_010 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_SOIL_020 = (
+            TEMPERATURE_SOIL_MEAN_020 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_SOIL_050 = (
+            TEMPERATURE_SOIL_MEAN_050 = (
+                OriginUnit.DEGREE_CELSIUS.value,
+                SIUnit.DEGREE_KELVIN.value,
+            )
+            TEMPERATURE_SOIL_MEAN_100 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -522,11 +562,11 @@ class DwdObservationUnit(DatasetTreeCore):
             QN_6 = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
             SNOW_DEPTH_EXCELLED = OriginUnit.CENTIMETER.value, SIUnit.METER.value
             SNOW_DEPTH = OriginUnit.CENTIMETER.value, SIUnit.METER.value
-            WATER_EQUIVALENT_TOTAL_SNOW_DEPTH = (
+            WATER_EQUIVALENT_SNOW_DEPTH = (
                 OriginUnit.MILLIMETER.value,
                 SIUnit.KILOGRAM_PER_SQUARE_METER.value,
             )
-            WATER_EQUIVALENT_SNOW = (
+            WATER_EQUIVALENT_SNOW_DEPTH_EXCELLED = (
                 OriginUnit.MILLIMETER.value,
                 SIUnit.KILOGRAM_PER_SQUARE_METER.value,
             )
@@ -534,21 +574,42 @@ class DwdObservationUnit(DatasetTreeCore):
         # weather_phenomena
         class WEATHER_PHENOMENA(UnitEnum):  # noqa
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            FOG = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            THUNDER = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            STORM_STRONG_WIND = (
+            COUNT_WEATHER_TYPE_FOG = (
                 OriginUnit.DIMENSIONLESS.value,
                 SIUnit.DIMENSIONLESS.value,
             )
-            STORM_STORMIER_WIND = (
+            COUNT_WEATHER_TYPE_THUNDER = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_STORM_STRONG_WIND = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_STORM_STORMIER_WIND = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_DEW = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_GLAZE = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_RIPE = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_SLEET = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_HAIL = (
                 OriginUnit.DIMENSIONLESS.value,
                 SIUnit.DIMENSIONLESS.value,
             )
-            DEW = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            GLAZE = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            RIPE = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            SLEET = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            HAIL = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
 
     # monthly
     class MONTHLY(DatasetTreeCore):
@@ -559,15 +620,15 @@ class DwdObservationUnit(DatasetTreeCore):
                 SIUnit.DIMENSIONLESS.value,
             )
             CLOUD_COVER_TOTAL = OriginUnit.ONE_EIGHTH.value, SIUnit.PERCENT.value
-            TEMPERATURE_AIR_200 = (
+            TEMPERATURE_AIR_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_AIR_MAX_MEAN_200 = (
+            TEMPERATURE_AIR_MAX_200_MEAN = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_AIR_MIN_MEAN_200 = (
+            TEMPERATURE_AIR_MIN_200_MEAN = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -615,20 +676,38 @@ class DwdObservationUnit(DatasetTreeCore):
         # weather_phenomena
         class WEATHER_PHENOMENA(UnitEnum):  # noqa
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            STORM_STRONG_WIND = (
+            COUNT_WEATHER_TYPE_STORM_STRONG_WIND = (
                 OriginUnit.DIMENSIONLESS.value,
                 SIUnit.DIMENSIONLESS.value,
             )
-            STORM_STORMIER_WIND = (
+            COUNT_WEATHER_TYPE_STORM_STORMIER_WIND = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_THUNDER = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_GLAZE = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_SLEET = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_HAIL = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_FOG = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_DEW = (
                 OriginUnit.DIMENSIONLESS.value,
                 SIUnit.DIMENSIONLESS.value,
             )
-            THUNDER = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            GLAZE = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            SLEET = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            HAIL = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            FOG = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            DEW = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
 
     # annual
     class ANNUAL(DatasetTreeCore):
@@ -639,15 +718,15 @@ class DwdObservationUnit(DatasetTreeCore):
                 SIUnit.DIMENSIONLESS.value,
             )
             CLOUD_COVER_TOTAL = OriginUnit.ONE_EIGHTH.value, SIUnit.PERCENT.value
-            TEMPERATURE_AIR_200 = (
+            TEMPERATURE_AIR_MEAN_200 = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_AIR_MAX_MEAN_200 = (
+            TEMPERATURE_AIR_MAX_200_MEAN = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
-            TEMPERATURE_AIR_MIN_MEAN_200 = (
+            TEMPERATURE_AIR_MIN_200_MEAN = (
                 OriginUnit.DEGREE_CELSIUS.value,
                 SIUnit.DEGREE_KELVIN.value,
             )
@@ -695,17 +774,35 @@ class DwdObservationUnit(DatasetTreeCore):
         # weather_phenomena
         class WEATHER_PHENOMENA(UnitEnum):  # noqa
             QUALITY = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            STORM_STRONG_WIND = (
+            COUNT_WEATHER_TYPE_STORM_STRONG_WIND = (
                 OriginUnit.DIMENSIONLESS.value,
                 SIUnit.DIMENSIONLESS.value,
             )
-            STORM_STORMIER_WIND = (
+            COUNT_WEATHER_TYPE_STORM_STORMIER_WIND = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_THUNDER = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_GLAZE = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_SLEET = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_HAIL = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_FOG = (
+                OriginUnit.DIMENSIONLESS.value,
+                SIUnit.DIMENSIONLESS.value,
+            )
+            COUNT_WEATHER_TYPE_DEW = (
                 OriginUnit.DIMENSIONLESS.value,
                 SIUnit.DIMENSIONLESS.value,
             )
-            THUNDER = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            GLAZE = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            SLEET = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            HAIL = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            FOG = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
-            DEW = OriginUnit.DIMENSIONLESS.value, SIUnit.DIMENSIONLESS.value
