@@ -17,7 +17,7 @@ from wetterdienst.provider.dwd.metadata.constants import NA_STRING, STATION_DATA
 from wetterdienst.provider.dwd.metadata.datetime import DatetimeFormat
 from wetterdienst.provider.dwd.observation.metadata.dataset import DwdObservationDataset
 from wetterdienst.provider.dwd.observation.metadata.parameter import (
-    DwdObservationDatasetTree,
+    DwdObservationParameter,
 )
 
 log = logging.getLogger(__name__)
@@ -25,11 +25,11 @@ log = logging.getLogger(__name__)
 # Parameter names used to create full 1 minute precipitation dataset wherever those
 # columns are missing (which is the case for non historical data)
 PRECIPITATION_PARAMETERS = (
-    DwdObservationDatasetTree.MINUTE_1.PRECIPITATION.PRECIPITATION_HEIGHT_DROPLET.value,
-    DwdObservationDatasetTree.MINUTE_1.PRECIPITATION.PRECIPITATION_HEIGHT_ROCKER.value,
+    DwdObservationParameter.MINUTE_1.PRECIPITATION.PRECIPITATION_HEIGHT_DROPLET.value,
+    DwdObservationParameter.MINUTE_1.PRECIPITATION.PRECIPITATION_HEIGHT_ROCKER.value,
 )
 
-PRECIPITATION_MINUTE_1_QUALITY = DwdObservationDatasetTree.MINUTE_1.PRECIPITATION.QUALITY
+PRECIPITATION_MINUTE_1_QUALITY = DwdObservationParameter.MINUTE_1.PRECIPITATION.QUALITY
 
 
 def parse_climate_observations_data(
@@ -52,12 +52,24 @@ def parse_climate_observations_data(
         pandas.DataFrame with requested data, for different station ids the data is
         still put into one DataFrame
     """
-
     data = [
         _parse_climate_observations_data(filename_and_file, dataset, resolution, period)
         for filename_and_file in filenames_and_files
     ]
 
+    if resolution == Resolution.SUBDAILY and dataset == DwdObservationDataset.WIND_EXTREME:
+        for i, df in enumerate(data):
+            if set(df.columns).issuperset(["qn_8", "fx_911_3"]):
+                data[i] = df.rename(columns={"qn_8": "qn_8_3"})
+            elif set(df.columns).issuperset(["qn_8", "fx_911_6"]):
+                data[i] = df.rename(columns={"qn_8": "qn_8_6"})
+
+        return (
+            pd.concat(data)
+            .reset_index(drop=True)
+            .reindex(columns=["station_id", "date", "qn_8_3", "fx_911_3", "qn_8_6", "fx_911_6"])
+        )
+
     return pd.concat(data).reset_index(drop=True)
 
 
@@ -83,10 +95,12 @@ def _parse_climate_observations_data(
 
     try:
         df = pd.read_csv(
-            filepath_or_buffer=BytesIO(file.read().replace(b" ", b"")),  # prevent leading/trailing whitespace
+            filepath_or_buffer=file,  # prevent leading/trailing whitespace
             sep=STATION_DATA_SEP,
             dtype="str",
             na_values=NA_STRING,
+            encoding="latin1",
+            skipinitialspace=True,
         )
     except pd.errors.ParserError:
         log.warning(f"The file representing {filename} could not be parsed and is skipped.")
@@ -104,22 +118,6 @@ def _parse_climate_observations_data(
     # End of record (EOR) has no value, so drop it right away.
     df = df.drop(columns=DwdColumns.EOR.value, errors="ignore")
 
-    # Special handling for hourly solar data, as it has more date columns
-    if resolution == Resolution.HOURLY and dataset == DwdObservationDataset.SOLAR:
-        # Rename date column correctly to end of interval, as it has additional minute
-        # information. Also rename column with true local time to english one
-        df = df.rename(
-            columns={
-                "mess_datum_woz": DwdObservationDatasetTree.HOURLY.SOLAR.TRUE_LOCAL_TIME.value,
-            }
-        )
-
-        # Duplicate the date column to end of interval column
-        df[DwdObservationDatasetTree.HOURLY.SOLAR.END_OF_INTERVAL.value] = df[DwdOrigColumns.DATE.value]
-
-        # Fix real date column by cutting of minutes
-        df[DwdOrigColumns.DATE.value] = df[DwdOrigColumns.DATE.value].str[:-3]
-
     if resolution == Resolution.MINUTE_1 and dataset == DwdObservationDataset.PRECIPITATION:
         # Need to unfold historical data, as it is encoded in its run length e.g.
         # from time X to time Y precipitation is 0
@@ -161,5 +159,30 @@ def _parse_climate_observations_data(
                 if parameter not in df:
                     df[parameter] = pd.NA
 
+    # Special handling for hourly solar data, as it has more date columns
+    if resolution == Resolution.HOURLY and dataset == DwdObservationDataset.SOLAR:
+        # Rename date column correctly to end of interval, as it has additional minute
+        # information. Also rename column with true local time to english one
+        df = df.rename(
+            columns={
+                "mess_datum_woz": DwdObservationParameter.HOURLY.SOLAR.TRUE_LOCAL_TIME.value,
+            }
+        )
+
+        # Duplicate the date column to end of interval column
+        df[DwdObservationParameter.HOURLY.SOLAR.END_OF_INTERVAL.value] = df[DwdOrigColumns.DATE.value]
+
+        # Fix real date column by cutting of minutes
+        df[DwdOrigColumns.DATE.value] = df[DwdOrigColumns.DATE.value].str[:-3]
+
+    if resolution in (Resolution.MONTHLY, Resolution.ANNUAL):
+        df = df.rename(
+            columns={
+                DwdOrigColumns.FROM_DATE.value: DwdColumns.DATE.value,
+                DwdOrigColumns.FROM_DATE_ALTERNATIVE.value: DwdColumns.DATE.value,
+            }
+        )
+        df = df.drop(columns=[DwdOrigColumns.TO_DATE.value, DwdOrigColumns.TO_DATE_ALTERNATIVE.value], errors="ignore")
+
     # Assign meaningful column names (baseline).
     return df.rename(columns=GERMAN_TO_ENGLISH_COLUMNS_MAPPING)
