@@ -9,12 +9,7 @@ from io import BytesIO
 from typing import Generator, Optional, Tuple, Union
 
 import pandas as pd
-import requests
-from fsspec.implementations.cached import WholeFileCacheFileSystem
-from fsspec.implementations.http import HTTPFileSystem
 from pandas._libs.tslibs.offsets import YearEnd
-from requests.adapters import HTTPAdapter
-from urllib3 import Retry
 
 from wetterdienst.core.scalar.request import ScalarRequestCore
 from wetterdienst.core.scalar.values import ScalarValuesCore
@@ -31,10 +26,10 @@ from wetterdienst.provider.eccc.observation.metadata.parameter import (
     EcccObservationParameter,
 )
 from wetterdienst.provider.eccc.observation.metadata.resolution import (
-    EccObservationResolution,
+    EcccObservationResolution,
 )
 from wetterdienst.provider.eccc.observation.metadata.unit import EcccObservationUnit
-from wetterdienst.util.cache import CacheExpiry, cache_dir
+from wetterdienst.util.cache import CacheExpiry
 from wetterdienst.util.network import download_file
 
 log = logging.getLogger(__name__)
@@ -50,9 +45,6 @@ class EcccObservationValues(ScalarValuesCore):
 
     _has_quality = True
 
-    _session = requests.Session()
-    _session.mount("https://", HTTPAdapter(max_retries=Retry(total=10, connect=5, read=5)))
-
     _base_url = (
         "https://climate.weather.gc.ca/climate_data/bulk_data_e.html?"
         "format=csv&stationID={0}&timeframe={1}"
@@ -241,7 +233,7 @@ class EcccObservationRequest(ScalarRequestCore):
 
     _tz = Timezone.UTC
 
-    _resolution_base = EccObservationResolution
+    _resolution_base = EcccObservationResolution
     _resolution_type = ResolutionType.MULTI
     _period_type = PeriodType.FIXED
     _period_base = Period.HISTORICAL
@@ -302,7 +294,7 @@ class EcccObservationRequest(ScalarRequestCore):
     def __init__(
         self,
         parameter: Tuple[Union[str, EcccObservationParameter]],
-        resolution: Union[EccObservationResolution, Resolution],
+        resolution: Union[EcccObservationResolution, Resolution],
         start_date: Optional[datetime] = None,
         end_date: Optional[datetime] = None,
     ):
@@ -323,14 +315,16 @@ class EcccObservationRequest(ScalarRequestCore):
 
     def _all(self) -> pd.DataFrame:
         # Acquire raw CSV payload.
-        csv_payload = self._download_stations()
+        csv_payload, source = self._download_stations()
+
+        header = source == 0 and 3 or 2
 
         # Read into Pandas data frame.
-        df = pd.read_csv(BytesIO(csv_payload), header=3, dtype=str)
+        df = pd.read_csv(csv_payload, header=header, dtype=str)
 
         df = df.rename(columns=str.lower)
 
-        df = df.drop(columns=["latitude", "longitude"])
+        df = df.drop(columns=["latitude", "longitude"], errors="ignore")
 
         df = df.rename(columns=self._columns_mapping)
 
@@ -339,42 +333,37 @@ class EcccObservationRequest(ScalarRequestCore):
         return df
 
     @staticmethod
-    def _download_stations() -> BytesIO:
+    def _download_stations() -> Tuple[BytesIO, int]:
         """
         Download station list from ECCC FTP server.
 
-        :return: CSV payload
+        :return: CSV payload, source identifier
         """
 
         gdrive_url = "https://drive.google.com/uc?id=1HDRnj41YBWpMioLPwAFiLlK4SK8NV72C"
-
         http_url = (
             "https://github.com/earthobservations/testdata/raw/main/ftp.tor.ec.gc.ca/Pub/"
             "Get_More_Data_Plus_de_donnees/Station%20Inventory%20EN.csv.gz"
         )
 
         payload = None
-
-        fs = WholeFileCacheFileSystem(
-            fs=HTTPFileSystem(),
-            cache_storage=cache_dir,
-            expiry_time=CacheExpiry.METAINDEX.value,
-        )
-
+        source = None
         try:
-            payload = fs.cat(gdrive_url)
+            payload = download_file(gdrive_url, CacheExpiry.METAINDEX)
+            source = 0
         except Exception:
             log.exception(f"Unable to access Google drive server at {gdrive_url}")
 
             # Fall back to different source.
             try:
-                response = fs.cat(http_url)
-                with gzip.open(BytesIO(response), mode="rb") as f:
-                    payload = f.read()
+                response = download_file(http_url, CacheExpiry.METAINDEX)
+                with gzip.open(response, mode="rb") as f:
+                    payload = BytesIO(f.read())
+                source = 1
             except Exception:
                 log.exception(f"Unable to access HTTP server at {http_url}")
 
         if payload is None:
             raise FailedDownload("Unable to acquire ECCC stations_result list")
 
-        return payload
+        return payload, source
