@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+# Copyright (c) 2018-2022, earthobservations developers.
+# Distributed under the MIT License. See LICENSE for more info.
 from contextvars import ContextVar
 from dataclasses import dataclass
 
@@ -20,6 +23,9 @@ class Settings:
             humanize: bool = env.bool("HUMANIZE", True)
             tidy: bool = env.bool("TIDY", True)
             si_units: bool = env.bool("SI_UNITS", True)
+            skip_empty: bool = env.bool("SKIP_EMPTY", False)
+            skip_threshold: bool = env.float("SKIP_THRESHOLD", 0.95)
+            dropna: bool = env.bool("DROPNA", False)
 
     @classmethod
     def reset(cls):
@@ -39,7 +45,8 @@ class Settings:
 
     # Context manager for managing settings in concurrent situations
     def __enter__(self):
-        self._local_settings_token = self._local_settings.set(self)
+        settings_token = self._local_settings.set(self)
+        self._local_settings.get()._local_settings_token = settings_token
         return self._local_settings.get()
 
     def __exit__(self, type_, value, traceback):
