@@ -98,6 +98,9 @@ def fetch_stations(provider: str, network: str, resolution: str, dataset: str, p
             si_units=True,
             tidy=True,
             humanize=True,
+            skip_empty=False,
+            skip_threshold=0.95,
+            dropna=False,
         )
     except (requests.exceptions.ConnectionError, InvalidParameterCombination) as ex:
         log.warning(ex)
@@ -169,6 +172,9 @@ def fetch_values(
             sql=None,
             sql_values=None,
             si_units=True,
+            skip_empty=False,
+            skip_threshold=0.95,
+            dropna=False,
             tidy=True,
             humanize=True,
         )
@@ -507,7 +513,8 @@ def set_parameter_options(provider, network, resolution, dataset):
         ]
 
     if api._period_type == PeriodType.FIXED:
-        periods = [{"label": api._period_base.name, "value": api._period_base.name}]
+        period = list(api._period_base)[0]
+        periods = [{"label": period.name, "value": period.name}]
     else:
         # Periods ALL placeholder, may use click options for multiple periods
         periods = [{"label": "ALL", "value": "ALL"}]
